==> haskell-css-text-0.1.3.0-385.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-css-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 css-text
version:              0.1.3.0
visibility:           public
id:                   css-text-0.1.3.0-BWAcyWZISYcHszluw9BWW5
key:                  css-text-0.1.3.0-BWAcyWZISYcHszluw9BWW5
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/yesodweb/css-text.git#readme
synopsis:             CSS parser and renderer.
description:
    Please see the README and generated docs at <https://www.stackage.org/package/css-text>

category:             Web, Yesod
abi:                  ade0382cd83cc3a3029fd47a6fd21378
exposed:              True
exposed-modules:      Text.CSS.Parse Text.CSS.Render
hidden-modules:       Paths_css_text
import-dirs:          /usr/lib/ghc-9.6.6/site-local/css-text-0.1.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/css-text-0.1.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/css-text-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-css-text
hs-libraries:         HScss-text-0.1.3.0-BWAcyWZISYcHszluw9BWW5
depends:
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-css-text/html/css-text.haddock
haddock-html:         /usr/share/doc/haskell-css-text/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-css-text-0.1.3.0-386-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-css-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 css-text
version:              0.1.3.0
visibility:           public
id:                   css-text-0.1.3.0-EabfuOGZPIdI0loquvBori
key:                  css-text-0.1.3.0-EabfuOGZPIdI0loquvBori
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/yesodweb/css-text.git#readme
synopsis:             CSS parser and renderer.
description:
    Please see the README and generated docs at <https://www.stackage.org/package/css-text>

category:             Web, Yesod
abi:                  7c5ee4564516eeec1898ab4da64488cc
exposed:              True
exposed-modules:      Text.CSS.Parse Text.CSS.Render
hidden-modules:       Paths_css_text
import-dirs:          /usr/lib/ghc-9.6.6/site-local/css-text-0.1.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/css-text-0.1.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/css-text-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-css-text
hs-libraries:         HScss-text-0.1.3.0-EabfuOGZPIdI0loquvBori
depends:
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-css-text/html/css-text.haddock
haddock-html:         /usr/share/doc/haskell-css-text/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
